moviepy.video.fx.all.headblur — MoviePy 1.0.1 documentation

# moviepy.video.fx.all.headblur

`moviepy.video.fx.all.` `headblur`(clip, fx, fy, r_zone, r_blur=None)

  Returns a filter that will blurr a moving part (a head ?) of the frames. The position of the blur at time t is defined by (fx(t), fy(t)), the radius of the blurring by `r_zone` and the intensity of the blurring by `r_blur`. Requires OpenCV for the circling and the blurring. Automatically deals with the case where part of the image goes offscreen.